// vim: set tw=80 ts=4 sw=4 sts=4:
/*
    This file is part of Accountant.

    Accountant is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Accountant is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with Accountant.  If not, see <http://www.gnu.org/licenses/>.
 */
/* jshint node: true */
'use strict';

var angular = require('angular');

var ngStorage  = require('meanie-angular-storage'),
    ngHttpAuth = require('angular-http-auth'),
    ngUiBootstrap = require('angular-ui-bootstrap');

// Note: ngHttpAuth seems to have no module.exports.
ngHttpAuth = 'http-auth-interceptor';

var loginTmpl = require('./login.tmpl.html');

var LoginService = require('./login.service');
var LoginConfig = require('./login.config');
var LoginController = require('./login.controller');

var base64 = require('base64util');

module.exports = angular.module('accountant.login', [
    ngHttpAuth,
    ngStorage,
    ngUiBootstrap
])

    .service('LoginService', LoginService)

    .config(LoginConfig)

    .controller('LoginModalController', LoginController)

    .run(function($rootScope, LoginService) {
        var onAuthLoginRequired = $rootScope.$on('event:auth-loginRequired', LoginService.login);

        var onAuthLoginCancelled = $rootScope.$on('event:auth-loginCancelled', LoginService.cancelLogin);

        $rootScope.$on('$destroy', function() {
            onAuthLoginRequired = angular.noop();
            onAuthLoginCancelled = angular.noop();
        });
    })

    .name;
